function q=config(q,ang,nmodes,keff)
% Add an fc array to the combined LagrQuad structure
%     ... that is an array in "configuration" space
%(configuration space is just the decomposition by toroidal position
%where ang sets the first position, and nt gives number of positions - 
%note that this is where the fourier reconstruction occurs - obtaining the
%field at other azimuths from:
%q.fc = q.fc + f * cos(km*th)*real(q.f) + f * sin(km*th) * imag(q.f)
%where f is a factor, and th = ang + 2*pi*((k-1)/nt)) the toroidal angles

if nargin < 4
    error('**ERROR** function config requires 4 arguments!')
end

maxMode = max(keff);
nt = 2^(maxMode+1);
nt = max(nt,4);         % Always define at at least 4 azimuths 
q.nt = nt;

for k=1:nt
    q.fc(:,:,:,k) = 0*q.f(:,:,:,1);
end
nmodes=1;
for n=1:nmodes
    n;
    km = keff(n);
    if km == 0
        f = 1;
    else
        f = 2;
    end
    for k=1:nt
        k;
        th = ang + 2*pi*((k-1)/nt);
        cs = cos(km*th);
        sn = sin(km*th);
        q.fc(:,:,:,k) = q.fc(:,:,:,k) + ...
            f*cs*real(q.f(:,:,:,n)) + ...
            f*sn*imag(q.f(:,:,:,n));
    end
end
