function cb = makeCBstruct(d)
% Return structure of data on how to Combine Blocks.
%  This 1st function is just a switchyard to call the correct
%   version of this function, depending on the block structure.
%  It only works for a very simple and restricted set of block structures
%  where they uniformly fill a rectangular area, and all blocks are of
%  identical size.

if length(d.rb) == 1
    cb = 1;
    return
end
if length(d.rb) == 2
    cb = makeCBstructAxB(d, 1, 2);
%    cb = makeCBstructAxB(d, 2, 1);
elseif length(d.rb) == 4
%    cb = makeCBstructAxB(d, 2, 2);
    cb = makeCBstructAxB(d, 1, 4);
elseif length(d.rb) == 20
%    cb = makeCBstructAxB(d, 2, 2);
    cb = makeCBstructAxB(d, 2, 10);     
elseif length(d.rb) == 8
    cb = makeCBstructAxB(d, 2, 4);
%    cb = makeCBstructAxB(d, 1, 8);
elseif length(d.rb) == 12
    cb = makeCBstructAxB(d, 2, 6);
elseif length(d.rb) == 24
    cb = makeCBstructAxB(d, 3, 8);
elseif length(d.rb) == 28
    cb = makeCBstructAxB(d, 2, 14);    
elseif length(d.rb) == 32
    cb = makeCBstructAxB(d, 4, 8);
%    cb = makeCBstructAxB(d, 2, 16);
elseif length(d.rb) == 128	%added by JKB 10.07.2011
    cb = makeCBstructAxB(d, 4, 32);	%added by JKB 10.07.2011
elseif length(d.rb) == 16
%    cb = makeCBstructAxB(d, 4, 4);
    cb = makeCBstructAxB(d, 2, 8);
%elseif length(d.rb) == 64
%    cb = makeCBstructAxB(d, 8, 8);
elseif length(d.rb) == 64
    cb = makeCBstructAxB(d, 16, 4);


elseif length(d.rb) == 6
    cb = makeCBstructAxB(d, 2, 3);
%    cb = makeCBstructAxB(d, 1, 6);
elseif length(d.rb) == 14
    cb = makeCBstructAxB(d, 2, 7);
%    cb = makeCBstructAxB(d, 1, 14);
else
    error('** ERROR ** Need to write new routine to handle block struct');
end

% *-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-

function cb = makeCBstructAxB(d, nxbl, nybl)
% Return the structure of data on how to Combine Blocks

% This works for a set of nxbl x nybl equal sized blocks arranged as
%
% nybl   nxbl*nybl
%
%  1     nybl + 1
%

mx = nxbl*d.rb{1}.mx;
my = nybl*d.rb{1}.my;
poly_degree = d.poly_degree;

if nxbl*nybl ~= length(d.rb)
    error('**Error** dimensions in make CBstruct not consistent with data')
end

nx = 1 + (poly_degree*mx)/nxbl;     % Dimension in each block
ny = 1 + (poly_degree*my)/nybl;     % Dimension in each block

cb.nx = 1 + (poly_degree * mx);     % Dimension in combined block
cb.ny = 1 + (poly_degree * my);     % Dimension in compined block

for nxb=1:nxbl
    for nyb=1:nybl
        nblock = nyb + (nxb-1)*nybl;
        i1 = 1 + (nxb-1)*(nx-1);
        i2 = i1 + (nx-1);
        j1 = 1 + (nyb-1)*(ny-1);
        j2 = j1 + (ny-1);
        cb.bl{nblock}.i1 = i1;
        cb.bl{nblock}.i2 = i2;
        cb.bl{nblock}.j1 = j1;
        cb.bl{nblock}.j2 = j2;
    end
end
